@@ -12,6 +12,8 @@ class ErrorCode:
     UN_RECOGNIZED_FIELD = 1200
     FIELD_VALUE_ERROR = 1300
     FIELD_MIN_RANGE_EXCEEDED = 1310
+    FIELD_MIN_LENGTH_VIOLATED = 1311
     FIELD_MAX_RANGE_EXCEEDED = 1315
+    FIELD_MAX_LENGTH_VIOLATED = 1316
     FIELD_VALUE_NOT_IN_ALLOWED_LIST = 1320
     FIELD_REGEX_VALIDATION_FAILED = 1330
